@@ -88,6 +88,15 @@ class ObjectNotFoundError(ConfigurationError):
         super().__init__(f"Object '{name}' in '{trace}' does not exist.")
 
 
+class ClassIsNotString(ConfigurationError):
+    def __init__(
+        self,
+        trace: str,
+    ) -> None:
+        self.trace = trace
+        super().__init__(f"Class path in '{trace}' is not string.")
+
+
 class ObjectNotRegistered(ConfigurationError):
     def __init__(
         self,
