@@ -689,7 +689,8 @@ class Smart(Generic[T]):
             if args.path.exists():
                 self.update_from(args.path)
             if args.mode:
-                self.update_from(args.path.with_suffix(f'.{args.mode}{args.path.suffix}'))
+                for path_mode in strutil.get_mode_paths(args.path, args.mode):
+                    self.update_from(path_mode)
 
         self.update_from(args.params)
 
