@@ -1,11 +1,14 @@
 import json
-from typing import Any, Optional, Tuple
+from pathlib import Path
+from typing import Any, List, Optional, Tuple
 
 from smartparams.exceptions import ArgumentParserError
 
 KEY_SEPARATOR = '.'
 OBJECT_SEPARATOR = ':'
 PARAM_SEPARATOR = '='
+MODE_SEPARATOR = ','
+PATH_SEPARATOR = '/'
 
 
 def join_keys(*args: Optional[str]) -> str:
@@ -39,3 +42,16 @@ def to_bool(value: str) -> bool:
         return False
 
     raise ValueError(f"String value '{value}' is not like to boolean.")
+
+
+def get_mode_paths(
+    path: Path,
+    mode: str,
+) -> List[Path]:
+    mode_paths = []
+    for mode in mode.split(MODE_SEPARATOR):
+        *sub_dir, mode = mode.split(PATH_SEPARATOR)
+        suffix = f'.{mode}{path.suffix}'
+        mode_paths.append(path.parent.joinpath(*sub_dir, path.stem).with_suffix(suffix))
+
+    return mode_paths
