@@ -72,6 +72,33 @@ class TestSmartRunCase(IntegrationCase):
     def test_run__dump_no_path(self) -> None:
         self.assertRaises(MissingDumpPath, self.smart.run, function=Mock(), path=None)
 
+    @patch('smartparams.utils.cli.sys', Mock(argv='script.py'.split()))
+    def test_run__mode(self) -> None:
+        self.smart._callable = Mock()
+        with tempfile.TemporaryDirectory() as name:
+            temp_dir = Path(name)
+            path = temp_dir.joinpath('params.yaml')
+            path.write_text('a: 1\nb: 2\nc.a: 11\nc.b: 22')
+            temp_dir.joinpath('params.dev.yaml').write_text('b: -2\nc.b: -22\nc.c: -33')
+            temp_dir.joinpath('data').mkdir()
+            temp_dir.joinpath('models', 'baselines').mkdir(parents=True)
+            temp_dir.joinpath('data', 'params.d1.yaml').write_text('d: foo\ne: buu')
+            temp_dir.joinpath('models', 'baselines', 'params.m1.yaml').write_text('e: boo\nc.b: 0')
+
+            self.smart.run(
+                path=path,
+                mode='dev,data/d1,models/baselines/m1',
+            )
+
+        self.smart._callable.assert_called_once_with(
+            arg2=10,
+            a=1,
+            b=-2,
+            c={'a': 11, 'b': 0, 'c': -33},
+            d='foo',
+            e='boo',
+        )
+
     @patch('smartparams.utils.cli.sys', Mock(argv='script.py --print params'.split()))
     @patch('smartparams.utils.io.print')
     def test_run__print_params(self, print_mock: Mock) -> None:
